pub struct WebGL2State { /* private fields */ }Expand description
The graphics state.
This type represents the current state of a given graphics context. It acts as a forward-gate to all the exposed features from the low-level API but adds a small cache layer over it to prevent from issuing the same API call (with the same parameters).
Implementations
Sourceimpl WebGL2State
impl WebGL2State
Sourcepub fn get_max_texture_array_elements(&mut self) -> Option<usize>
pub fn get_max_texture_array_elements(&mut self) -> Option<usize>
Get the number of maximum elements an array texture can hold.
Cache the number on the first call and then re-use it for later calls.